summaryrefslogtreecommitdiffstats
path: root/c++/src/H5CommonFG.cpp
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2005-07-24 17:52:43 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2005-07-24 17:52:43 (GMT)
commitf208550696646adcc6e59e339745b0433e28f770 (patch)
treecd1c0a8b8283d5fa128d988bb335f85dfa390931 /c++/src/H5CommonFG.cpp
parent3cba75f060cafc0171e48cc3cc2ef17a20bf82ea (diff)
downloadhdf5-f208550696646adcc6e59e339745b0433e28f770.zip
hdf5-f208550696646adcc6e59e339745b0433e28f770.tar.gz
hdf5-f208550696646adcc6e59e339745b0433e28f770.tar.bz2
[svn-r11149] Purpose: Fix bugzilla #406
Description: Added these missing member functions: AbstractDs::getArrayType AbstractDs::getVarLenType CommonFG::openArrayType CommonFG::openVarLenType CompType::getMemberArrayType CompType::getMemberVarLenType Platforms tested: Linux 2.4 (heping) IRIX64 with -n32 (modi4) Linux 2.4 w/PGI (colonelk)
Diffstat (limited to 'c++/src/H5CommonFG.cpp')
-rw-r--r--c++/src/H5CommonFG.cpp82
1 files changed, 67 insertions, 15 deletions
diff --git a/c++/src/H5CommonFG.cpp b/c++/src/H5CommonFG.cpp
index 7771c40..40558c1 100644
--- a/c++/src/H5CommonFG.cpp
+++ b/c++/src/H5CommonFG.cpp
@@ -639,30 +639,30 @@ DataType CommonFG::openDataType( const string& name ) const
}
//--------------------------------------------------------------------------
// Function: CommonFG::openEnumType
///\brief Opens the named enumeration datatype at this location.
///\param name - IN: Name of the enumeration datatype to open
///\return EnumType instance
///\exception H5::FileIException or H5::GroupIException
-// Programmer Binh-Minh Ribler - 2000
+// Programmer Binh-Minh Ribler - Jul, 2005
//--------------------------------------------------------------------------
-EnumType CommonFG::openEnumType( const char* name ) const
+ArrayType CommonFG::openArrayType( const char* name ) const
{
- EnumType enum_type(p_open_data_type(name));
- return(enum_type);
-}
+ ArrayType array_type(p_open_data_type(name));
+ return(array_type);
+}
//--------------------------------------------------------------------------
-// Function: CommonFG::openEnumType
+// Function: CommonFG::openArrayType
///\brief This is an overloaded member function, provided for convenience.
-/// It differs from the above function in that it takes an
+/// It differs from the above function in that it takes an
/// \c std::string for \a name.
-// Programmer Binh-Minh Ribler - 2000
+// Programmer Binh-Minh Ribler - Jul, 2005
//--------------------------------------------------------------------------
-EnumType CommonFG::openEnumType( const string& name ) const
+ArrayType CommonFG::openArrayType( const string& name ) const
{
- return( openEnumType( name.c_str()) );
-}
+ return( openArrayType( name.c_str()) );
+}
//--------------------------------------------------------------------------
// Function: CommonFG::openCompType
@@ -691,6 +691,32 @@ CompType CommonFG::openCompType( const string& name ) const
}
//--------------------------------------------------------------------------
+// Function: CommonFG::openEnumType
+///\brief Opens the named enumeration datatype at this location.
+///\param name - IN: Name of the enumeration datatype to open
+///\return EnumType instance
+///\exception H5::FileIException or H5::GroupIException
+// Programmer Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+EnumType CommonFG::openEnumType( const char* name ) const
+{
+ EnumType enum_type(p_open_data_type(name));
+ return(enum_type);
+}
+
+//--------------------------------------------------------------------------
+// Function: CommonFG::openEnumType
+///\brief This is an overloaded member function, provided for convenience.
+/// It differs from the above function in that it takes an
+/// \c std::string for \a name.
+// Programmer Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+EnumType CommonFG::openEnumType( const string& name ) const
+{
+ return( openEnumType( name.c_str()) );
+}
+
+//--------------------------------------------------------------------------
// Function: CommonFG::openIntType
///\brief Opens the named integer datatype at this location.
///\param name - IN: Name of the integer datatype to open
@@ -769,6 +795,32 @@ StrType CommonFG::openStrType( const string& name ) const
}
//--------------------------------------------------------------------------
+// Function: CommonFG::openVarLenType
+///\brief Opens the named variable length datatype at this location.
+///\param name - IN: Name of the variable length datatype to open
+///\return VarLenType instance
+///\exception H5::FileIException or H5::GroupIException
+// Programmer Binh-Minh Ribler - Jul, 2005
+//--------------------------------------------------------------------------
+VarLenType CommonFG::openVarLenType( const char* name ) const
+{
+ VarLenType varlen_type(p_open_data_type(name));
+ return(varlen_type);
+}
+
+//--------------------------------------------------------------------------
+// Function: CommonFG::openVarLenType
+///\brief This is an overloaded member function, provided for convenience.
+/// It differs from the above function in that it takes an
+/// \c std::string for \a name.
+// Programmer Binh-Minh Ribler - Jul, 2005
+//--------------------------------------------------------------------------
+VarLenType CommonFG::openVarLenType( const string& name ) const
+{
+ return( openVarLenType( name.c_str()) );
+}
+
+//--------------------------------------------------------------------------
// Function: CommonFG::iterateElems
///\brief Iterates a user's function over the entries of a group.
///\param name - IN : Name of group to iterate over
@@ -639,30 +639,30 @@ DataType CommonFG::openDataType( const string& name ) const
}
//--------------------------------------------------------------------------
-// Function: CommonFG::openEnumType
-///\brief Opens the named enumeration datatype at this location.
-///\param name - IN: Name of the enumeration datatype to open
-///\return EnumType instance
+// Function: CommonFG::openArrayType
+///\brief Opens the named array datatype at this location.
+///\param name - IN: Name of the array datatype to open
+///\return ArrayType instance
///\exception H5::FileIException or H5::GroupIException